<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Theme</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+20"/>
        <source>User Interface Theme:</source>
        <translation>Tema uporabniškega vmesnika:</translation>
    </message>
</context>
<context>
    <name>ThemePreferences</name>
    <message>
        <location filename="../ThemePreferences.js" line="+30"/>
        <source>General</source>
        <translation>Splošno</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Theme</source>
        <translation>Tema</translation>
    </message>
</context>
</TS>
